@@ -1,7 +1,8 @@
 /*
   Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
   2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014,
-  2015 Free Software Foundation, Inc.
+  2015, 2016, 2017, 2018, 2019, 2020, 2021 Free Software Foundation,
+  Inc.
 
   This file is part of GNU Inetutils.
 
@@ -83,7 +84,9 @@
 #include <stdarg.h>
 #include <sys/select.h>
 
-#ifdef HAVE_IDNA_H
+#if defined HAVE_IDN2_H && defined HAVE_IDN2
+# include <idn2.h>
+#elif defined HAVE_IDNA_H
 # include <idna.h>
 #endif
 
@@ -105,10 +108,6 @@ extern int fclose (FILE *);
 extern int pclose (FILE *);
 #endif
 
-#ifndef __CYGWIN__
-extern int h_errno;
-#endif
-
 int data = -1;
 int abrtflag = 0;
 jmp_buf ptabort;
@@ -140,9 +139,13 @@ hookup (char *host, int port)
   int s, tos;
   socklen_t len;
   static char hostnamebuf[80];
-  char *rhost;
+  char *rhost, *p;
 
-#ifdef HAVE_IDN
+  p = strrchr (host, '@');
+  if (p && p != host && isprint (p[1]))
+    host = ++p;
+
+#if defined HAVE_IDN || defined HAVE_IDN2
   status = idna_to_ascii_lz (host, &rhost, 0);
   if (status)
     {
@@ -150,7 +153,7 @@ hookup (char *host, int port)
       code = -1;
       return ((char *) 0);
     }
-#else /* !HAVE_IDN */
+#else /* !HAVE_IDN && !HAVE_IDN2 */
   rhost = strdup (host);
 #endif
 
@@ -178,9 +181,10 @@ hookup (char *host, int port)
     }
 
   if (res->ai_canonname)
-    strncpy (hostnamebuf, res->ai_canonname, sizeof (hostnamebuf));
+    strncpy (hostnamebuf, res->ai_canonname, sizeof (hostnamebuf) - 1);
   else
-    strncpy (hostnamebuf, rhost, sizeof (hostnamebuf));
+    strncpy (hostnamebuf, rhost, sizeof (hostnamebuf) - 1);
+  hostnamebuf[sizeof (hostnamebuf) - 1] = 0;
 
   hostname = hostnamebuf;
   free (rhost);
@@ -299,8 +303,11 @@ bad:
 int
 login (char *host)
 {
+#if !HAVE_DECL_GETPASS
+  extern char *getpass ();
+#endif
   char tmp[80];
-  char *user, *pass, *acct;
+  char *user, *pass, *acct, *p;
   int n, aflag = 0;
 
   user = pass = acct = 0;
@@ -309,6 +316,15 @@ login (char *host)
       code = -1;
       return (0);
     }
+
+  p = strrchr (host, '@');
+  if (user == NULL && p && p != host && isprint (p[1]))
+    {
+      *p = 0;
+      user = host;
+      host = ++p;
+    }
+
   while (user == NULL)
     {
       char *myname = getlogin ();
@@ -529,7 +545,10 @@ getreply (int expecteof)
 	  if (pflag == 2)
 	    {
 	      if (c != '\r' && c != ')')
-		*pt++ = c;
+		{
+		  if (pt < &pasv[sizeof(pasv) - 1])
+		    *pt++ = c;
+		}
 	      else
 		{
 		  *pt = '\0';
@@ -1748,10 +1767,10 @@ pswitch (int flag)
   ip->ntflg = ntflag;
   ntflag = op->ntflg;
   strncpy (ip->nti, ntin, sizeof (ntin) - 1);
-  (ip->nti)[strlen (ip->nti)] = '\0';
+  (ip->nti)[sizeof (ntin) - 1] = '\0';
   strcpy (ntin, op->nti);
   strncpy (ip->nto, ntout, sizeof (ntout) - 1);
-  (ip->nto)[strlen (ip->nto)] = '\0';
+  (ip->nto)[sizeof (ntout) - 1] = '\0';
   strcpy (ntout, op->nto);
   ip->mapflg = mapflag;
   mapflag = op->mapflg;
