@@ -17,7 +17,7 @@
 
 #define YYPURE 0
 
-#line 73 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 74 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 
 #include <config.h>
 
@@ -92,7 +92,7 @@ static void yyerror       (const char *s);
 #endif
 #ifndef YYSTYPE_IS_DECLARED
 #define YYSTYPE_IS_DECLARED 1
-#line 143 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 144 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 typedef union {
 	intmax_t i;
 	char   *s;
@@ -555,7 +555,7 @@ typedef struct {
 } YYSTACKDATA;
 /* variables for the parser stack */
 static YYSTACKDATA yystack;
-#line 1311 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1312 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 
 #define	CMD	0	/* beginning of command */
 #define	ARGS	1	/* expect miscellaneous arguments */
@@ -1476,7 +1476,7 @@ yyreduce:
     switch (yyn)
     {
 case 2:
-#line 189 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 190 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			free (fromname);
 			fromname = (char *) 0;
@@ -1484,14 +1484,14 @@ case 2:
 		}
 break;
 case 4:
-#line 199 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 200 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			user (yystack.l_mark[-1].s);
 			free (yystack.l_mark[-1].s);
 		}
 break;
 case 5:
-#line 204 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 205 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			pass (yystack.l_mark[-1].s);
 			memset (yystack.l_mark[-1].s, 0, strlen (yystack.l_mark[-1].s));
@@ -1499,7 +1499,7 @@ case 5:
 		}
 break;
 case 6:
-#line 210 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 211 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i)
 			  {
@@ -1540,14 +1540,14 @@ case 6:
 		}
 break;
 case 7:
-#line 249 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 250 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-1].i)
 			  passive (PASSIVE_PASV, AF_INET);
 		}
 break;
 case 8:
-#line 254 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 255 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			switch (cmd_type)
 			  {
@@ -1587,7 +1587,7 @@ case 8:
 		}
 break;
 case 9:
-#line 292 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 293 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			switch (yystack.l_mark[-1].i)
 			  {
@@ -1601,7 +1601,7 @@ case 9:
 		}
 break;
 case 10:
-#line 304 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 305 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			switch (yystack.l_mark[-1].i)
 			  {
@@ -1615,19 +1615,19 @@ case 10:
 		}
 break;
 case 11:
-#line 316 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 317 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			reply (202, "ALLO command ignored.");
 		}
 break;
 case 12:
-#line 320 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 321 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			reply (202, "ALLO command ignored.");
 		}
 break;
 case 13:
-#line 324 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 325 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i && yystack.l_mark[-1].s != NULL)
 			  retrieve ((char *) 0, yystack.l_mark[-1].s);
@@ -1635,7 +1635,7 @@ case 13:
 		}
 break;
 case 14:
-#line 330 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 331 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i && yystack.l_mark[-1].s != NULL)
 			  store (yystack.l_mark[-1].s, "w", 0);
@@ -1643,7 +1643,7 @@ case 14:
 		}
 break;
 case 15:
-#line 336 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 337 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i && yystack.l_mark[-1].s != NULL)
 			  store (yystack.l_mark[-1].s, "a", 0);
@@ -1651,14 +1651,14 @@ case 15:
 		}
 break;
 case 16:
-#line 342 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 343 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-1].i)
 			  send_file_list (".");
 		}
 break;
 case 17:
-#line 347 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 348 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i && yystack.l_mark[-1].s != NULL)
 			  send_file_list (yystack.l_mark[-1].s);
@@ -1666,14 +1666,14 @@ case 17:
 		}
 break;
 case 18:
-#line 353 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 354 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-1].i)
 			  retrieve ("/bin/ls -lgA", "");
 		}
 break;
 case 19:
-#line 358 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 359 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i && yystack.l_mark[-1].s != NULL)
 			  retrieve ("/bin/ls -lgA %s", yystack.l_mark[-1].s);
@@ -1681,7 +1681,7 @@ case 19:
 		}
 break;
 case 20:
-#line 364 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 365 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i && yystack.l_mark[-1].s != NULL)
 			  statfilecmd (yystack.l_mark[-1].s);
@@ -1689,13 +1689,13 @@ case 20:
 		}
 break;
 case 21:
-#line 370 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 371 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			statcmd ();
 		}
 break;
 case 22:
-#line 374 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 375 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i && yystack.l_mark[-1].s != NULL)
 			  delete (yystack.l_mark[-1].s);
@@ -1703,7 +1703,7 @@ case 22:
 		}
 break;
 case 23:
-#line 380 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 381 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i)
 			  {
@@ -1720,20 +1720,20 @@ case 23:
 		}
 break;
 case 24:
-#line 395 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 396 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			reply (225, "ABOR command successful.");
 		}
 break;
 case 25:
-#line 399 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 400 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-1].i)
 			  cwd (cred.homedir);
 		}
 break;
 case 26:
-#line 404 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 405 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i && yystack.l_mark[-1].s != NULL)
 			  cwd (yystack.l_mark[-1].s);
@@ -1741,13 +1741,13 @@ case 26:
 		}
 break;
 case 27:
-#line 410 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 411 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			help (cmdtab, (char *) 0);
 		}
 break;
 case 28:
-#line 414 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 415 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			char *cp = yystack.l_mark[-1].s;
 
@@ -1767,13 +1767,13 @@ case 28:
 		}
 break;
 case 29:
-#line 432 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 433 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			reply (200, "NOOP command successful.");
 		}
 break;
 case 30:
-#line 436 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 437 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i && yystack.l_mark[-1].s != NULL)
 			  makedir (yystack.l_mark[-1].s);
@@ -1781,7 +1781,7 @@ case 30:
 		}
 break;
 case 31:
-#line 442 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 443 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i && yystack.l_mark[-1].s != NULL)
 			  removedir (yystack.l_mark[-1].s);
@@ -1789,21 +1789,21 @@ case 31:
 		}
 break;
 case 32:
-#line 448 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 449 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-1].i)
 			  pwd ();
 		}
 break;
 case 33:
-#line 453 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 454 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-1].i)
 			  cwd ("..");
 		}
 break;
 case 34:
-#line 458 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 459 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-1].i)
 			  {
@@ -1817,7 +1817,7 @@ case 34:
 		}
 break;
 case 35:
-#line 471 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 472 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i)
 			  {
@@ -1827,7 +1827,7 @@ case 35:
 		}
 break;
 case 36:
-#line 483 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 484 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-1].i)
 			  {
@@ -1836,7 +1836,7 @@ case 36:
 		}
 break;
 case 37:
-#line 490 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 491 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i)
 			  {
@@ -1846,20 +1846,20 @@ case 37:
 		}
 break;
 case 38:
-#line 498 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 499 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			help (sitetab, (char *) 0);
 		}
 break;
 case 39:
-#line 502 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 503 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			help (sitetab, yystack.l_mark[-1].s);
 			free (yystack.l_mark[-1].s);
 		}
 break;
 case 40:
-#line 507 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 508 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			int oldmask;
 
@@ -1872,7 +1872,7 @@ case 40:
 		}
 break;
 case 41:
-#line 518 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 519 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			int oldmask;
 
@@ -1890,7 +1890,7 @@ case 41:
 		}
 break;
 case 42:
-#line 534 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 535 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-5].i && (yystack.l_mark[-1].s != NULL))
 			  {
@@ -1906,7 +1906,7 @@ case 42:
 		}
 break;
 case 43:
-#line 548 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 549 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			reply (200,
 			       "Current IDLE time limit is %d seconds; max %d",
@@ -1914,7 +1914,7 @@ case 43:
 		}
 break;
 case 44:
-#line 554 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 555 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i)
 			  {
@@ -1934,7 +1934,7 @@ case 44:
 		}
 break;
 case 45:
-#line 572 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 573 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i && yystack.l_mark[-1].s != NULL)
 			  store (yystack.l_mark[-1].s, "w", 1);
@@ -1942,7 +1942,7 @@ case 45:
 		}
 break;
 case 46:
-#line 578 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 579 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 		        const char *sys_type; /* Official rfc-defined os type.  */
 			char *version = 0; /* A more specific type. */
@@ -1981,7 +1981,7 @@ case 46:
 		}
 break;
 case 47:
-#line 622 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 623 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i && yystack.l_mark[-1].s != NULL)
 			  sizecmd (yystack.l_mark[-1].s);
@@ -1989,7 +1989,7 @@ case 47:
 		}
 break;
 case 48:
-#line 637 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 638 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i && yystack.l_mark[-1].s != NULL)
 			  {
@@ -2015,7 +2015,7 @@ case 48:
 		}
 break;
 case 49:
-#line 665 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 666 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			usedefault = 0;
 			if (pdata >= 0)
@@ -2164,14 +2164,14 @@ case 49:
 		}
 break;
 case 50:
-#line 816 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 817 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-1].i)
 			  passive (PASSIVE_EPSV, AF_UNSPEC);
 		}
 break;
 case 51:
-#line 821 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 822 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i)
 			  {
@@ -2184,7 +2184,7 @@ case 51:
 		}
 break;
 case 52:
-#line 836 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 837 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-3].i)
 			  {
@@ -2223,27 +2223,27 @@ case 52:
 		}
 break;
 case 53:
-#line 877 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 878 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (yystack.l_mark[-1].i)
 			  passive (PASSIVE_LPSV, 0 /* not used */);
 		}
 break;
 case 54:
-#line 883 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 884 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			reply (221, "Goodbye.");
 			dologout (0);
 		}
 break;
 case 55:
-#line 888 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 889 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			yyerrok;
 		}
 break;
 case 56:
-#line 894 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 895 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			restart_point = (off_t) 0;
 			if (yystack.l_mark[-3].i && yystack.l_mark[-1].s)
@@ -2256,7 +2256,7 @@ case 56:
 		}
 break;
 case 57:
-#line 909 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 910 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 		        free (fromname);
 			fromname = (char *) 0;
@@ -2267,13 +2267,13 @@ case 57:
 		}
 break;
 case 59:
-#line 925 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 926 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			yyval.s = (char *) calloc (1, sizeof (char));
 		}
 break;
 case 62:
-#line 937 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 938 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			/* Rewrite as valid address family.  */
 			if (yystack.l_mark[0].i == 1)
@@ -2285,7 +2285,7 @@ case 62:
 		}
 break;
 case 65:
-#line 959 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 960 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			int err;
 			char a[INET6_ADDRSTRLEN], p[8];
@@ -2332,7 +2332,7 @@ case 65:
 		}
 break;
 case 66:
-#line 1009 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1010 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			int err;
 			char a[INET6_ADDRSTRLEN], p[8];
@@ -2394,7 +2394,7 @@ case 66:
 		}
 break;
 case 67:
-#line 1074 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1075 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			int err;
 			char a[INET6_ADDRSTRLEN], p[8];
@@ -2457,116 +2457,116 @@ case 67:
 		}
 break;
 case 68:
-#line 1138 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1139 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			yyval.i = FORM_N;
 		}
 break;
 case 69:
-#line 1142 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1143 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			yyval.i = FORM_T;
 		}
 break;
 case 70:
-#line 1146 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1147 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			yyval.i = FORM_C;
 		}
 break;
 case 71:
-#line 1153 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1154 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			cmd_type = TYPE_A;
 			cmd_form = FORM_N;
 		}
 break;
 case 72:
-#line 1158 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1159 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			cmd_type = TYPE_A;
 			cmd_form = yystack.l_mark[0].i;
 		}
 break;
 case 73:
-#line 1163 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1164 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			cmd_type = TYPE_E;
 			cmd_form = FORM_N;
 		}
 break;
 case 74:
-#line 1168 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1169 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			cmd_type = TYPE_E;
 			cmd_form = yystack.l_mark[0].i;
 		}
 break;
 case 75:
-#line 1173 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1174 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			cmd_type = TYPE_I;
 		}
 break;
 case 76:
-#line 1177 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1178 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			cmd_type = TYPE_L;
 			cmd_bytesz = NBBY;
 		}
 break;
 case 77:
-#line 1182 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1183 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			cmd_type = TYPE_L;
 			cmd_bytesz = yystack.l_mark[0].i;
 		}
 break;
 case 78:
-#line 1188 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1189 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			cmd_type = TYPE_L;
 			cmd_bytesz = yystack.l_mark[0].i;
 		}
 break;
 case 79:
-#line 1196 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1197 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			yyval.i = STRU_F;
 		}
 break;
 case 80:
-#line 1200 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1201 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			yyval.i = STRU_R;
 		}
 break;
 case 81:
-#line 1204 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1205 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			yyval.i = STRU_P;
 		}
 break;
 case 82:
-#line 1211 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1212 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			yyval.i = MODE_S;
 		}
 break;
 case 83:
-#line 1215 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1216 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			yyval.i = MODE_B;
 		}
 break;
 case 84:
-#line 1219 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1220 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			yyval.i = MODE_C;
 		}
 break;
 case 85:
-#line 1226 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1227 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			/*
 			 * Problem: this production is used for all pathname
@@ -2606,7 +2606,7 @@ case 85:
 		}
 break;
 case 87:
-#line 1271 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1272 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			int ret, dec, multby, digit;
 
@@ -2633,7 +2633,7 @@ case 87:
 		}
 break;
 case 88:
-#line 1299 "/cygdrive/c/cygwin/home/yano/inetutils-1.9.4-1.src/inetutils-1.9.4-1.x86_64/src/inetutils-1.9.4/ftpd/ftpcmd.y"
+#line 1300 "/home/yano/inetutils-release/inetutils-2.0-1.src/inetutils-2.0-1.i686/src/inetutils-2.0/ftpd/ftpcmd.y"
 	{
 			if (cred.logged_in)
 			  yyval.i = 1;
